"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CodeCommit = require("aws-sdk/clients/codecommit");
const SES = require("aws-sdk/clients/ses");
const SSM = require("aws-sdk/clients/ssm");
const common_1 = require("./common");
const codecommit = new CodeCommit();
const ses = new SES();
const ssm = new SSM();
const getSsmParams = (source, cc) => __awaiter(void 0, void 0, void 0, function* () {
    console.log(`Fetching SSM params (source: ${source}), (cc: ${cc})`);
    const paramNames = [source];
    if (cc) {
        paramNames.push(cc);
    }
    const resp = yield ssm.getParameters({
        Names: paramNames,
        WithDecryption: true
    }).promise();
    const paramMap = {};
    resp.Parameters.forEach((param) => {
        if (param.Name === source) {
            paramMap.SOURCE_EMAIL = param.Value;
        }
        else if (cc && param.Name === cc) {
            paramMap.CC_EMAIL = param.Value;
        }
    });
    return paramMap;
});
const ssmParams = getSsmParams(process.env.SOURCE_EMAIL_ADDR_PARAM, process.env.CC_EMAIL_ADDR_PARAM);
if (!ssmParams.SOURCE_EMAIL) {
    throw new Error("Could not retrieve source email address, unable to use SES without it");
}
exports.handler = (event = {}) => __awaiter(void 0, void 0, void 0, function* () {
    const buildenv = common_1.getBuildEnvironment(event.detail['additional-information'].environment['environment-variables']);
    if (!buildenv.CODECOMMIT_PULL_REQUEST_ID) {
        throw new Error("Not a pull request build");
    }
    console.log(`Processing request for pull request ${buildenv.CODECOMMIT_PULL_REQUEST_ID} on ${buildenv.CODECOMMIT_SOURCE_COMMIT_ID}`);
    return codecommit.getCommit({
        commitId: buildenv.CODECOMMIT_SOURCE_COMMIT_ID,
        repositoryName: buildenv.CODECOMMIT_REPOSITORY_NAME
    }).promise()
        .then((resp) => {
        const emailAddr = resp.commit.committer.email;
        const userName = resp.commit.committer.name;
        console.log(`Notifying ${userName} at ${emailAddr}`);
        const subject = `Build failed on pull request ${buildenv.CODECOMMIT_PULL_REQUEST_ID}`;
        const url = common_1.getBuildJobUrl(event.detail['build-id']);
        const message = `Hey ${userName},

            Bad news! A build for ${buildenv.CODECOMMIT_REPOSITORY_NAME} has failed!

            Source Commit: ${resp.commit.commitId}

            ${resp.commit.message}

            ${url}
            `;
        return ses.sendEmail({
            Source: ssmParams.SOURCE_EMAIL,
            Destination: {
                ToAddresses: [
                    emailAddr,
                ],
                CcAddresses: [ssmParams.CC_EMAIL],
            },
            Message: {
                Body: {
                    Text: {
                        Data: message
                    }
                },
                Subject: {
                    Data: subject
                }
            }
        }).promise();
    });
});
